@@ -1,15 +1,15 @@
 
 module Config
 
-  VERSION == "1.6.2" or
-    raise "ruby lib version (1.6.2) doesn't match executable version (#{VERSION})"
+  VERSION == "1.6.3" or
+    raise "ruby lib version (1.6.3) doesn't match executable version (#{VERSION})"
 
 # This file was created by configrb when ruby was built. Any changes
 # made to this file will be lost the next time ruby is built.
   DESTDIR = '' if not defined? DESTDIR
   CONFIG = {}
   TOPDIR = File.dirname(__FILE__).sub!(%r'/lib/ruby/1\.6/i386\-msdosdjgpp\Z', '')
-  CONFIG["srcdir"] = "/home/pub/ruby/16/ruby-1.6.2"
+  CONFIG["srcdir"] = "/home/pub/ruby/16/dist/ruby-1.6.3"
   CONFIG["prefix"] = (TOPDIR || DESTDIR + "/usr/local")
   CONFIG["ruby_install_name"] = "ruby"
   CONFIG["EXEEXT"] = ".exe"
@@ -35,7 +35,7 @@ module Config
   CONFIG["mandir"] = "#{CONFIG[\"prefix\"]}/man"
   CONFIG["MAJOR"] = "1"
   CONFIG["MINOR"] = "6"
-  CONFIG["TEENY"] = "2"
+  CONFIG["TEENY"] = "3"
   CONFIG["host"] = "i586-pc-msdosdjgpp"
   CONFIG["host_alias"] = "i586-pc-msdosdjgpp"
   CONFIG["host_cpu"] = "i586"
@@ -61,6 +61,7 @@ module Config
   CONFIG["AS"] = ""
   CONFIG["DLLTOOL"] = ""
   CONFIG["WINDRES"] = ""
+  CONFIG["MWIN32"] = ""
   CONFIG["LN_S"] = "ln -s"
   CONFIG["SET_MAKE"] = ""
   CONFIG["OBJEXT"] = "o"
@@ -76,7 +77,7 @@ module Config
   CONFIG["STRIP"] = "strip"
   CONFIG["EXTSTATIC"] = ""
   CONFIG["setup"] = "Setup.dj"
-  CONFIG["MINIRUBY"] = "ruby -I/pub/ruby/16/djgpp -rfake"
+  CONFIG["MINIRUBY"] = "ruby -I/pub/ruby/16/dist/djgpp -rfake"
   CONFIG["PREP"] = "fake.rb"
   CONFIG["LIBRUBY_LDSHARED"] = "ld"
   CONFIG["LIBRUBY_DLDFLAGS"] = ""
@@ -93,7 +94,7 @@ module Config
   CONFIG["arch"] = "i386-msdosdjgpp"
   CONFIG["sitedir"] = "#{CONFIG[\"prefix\"]}/lib/ruby/site_ruby"
   CONFIG["configure_args"] = "--target=i386-msdosdjgpp --host=i586-pc-msdosdjgpp --build=i586-pc-linux-gnu --cache=../config.cache-djgpp"
-  CONFIG["compile_dir"] = "/home/pub/ruby/16/djgpp"
+  CONFIG["compile_dir"] = "/home/pub/ruby/16/dist/djgpp"
   MAKEFILE_CONFIG = {}
   CONFIG.each{|k,v| MAKEFILE_CONFIG[k] = v.dup}
   def Config::expand(val)
